| sampleDyadData | R Documentation |
A simulated directed dyadic dataset in long format, suitable for demonstrating the functions in this package. The dataset contains observations from a round-robin design in which each person in a group rated every other person. Ratings were collected at two time points.
sampleDyadData
A data frame with 1548 rows and 16 variables:
integer; group identification variable
integer; actor (rater) identification variable
integer; partner (ratee) identification variable
integer; time point identifier (1 or 2)
integer; directed dyad-level measure of contact frequency
integer; directed dyad-level measure of liking
numeric; actor-level measure of extraversion
numeric; actor-level measure of agreeableness
integer; actor-level binary gender indicator (1 = male)
integer; actor-level age in years
numeric; partner-level measure of extraversion
numeric; partner-level measure of agreeableness
integer; partner-level binary gender indicator (1 = male)
integer; partner-level age in years
numeric; group-level measure of cohesion
numeric; group-level measure of efficacy
Simulated data created for package demonstration purposes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.